.. _modules-node_attributes:

#################
 Node attributes
#################

.. automodule:: anemoi.graphs.nodes.attributes
   :members:
   :exclude-members: BaseWeights
   :no-undoc-members:
   :show-inheritance:
